from typing import Any, Dict, Union

from fastapi import APIRouter, Depends, status

from app.api.dependencies import decode_bearer_token
from app.api.endpoints import bucket_permissions, buckets, s3key
from app.schemas.security import ErrorDetail

alternative_responses: Dict[Union[int, str], Dict[str, Any]] = {
    status.HTTP_400_BAD_REQUEST: {
        "model": ErrorDetail,
        "description": "Error decoding JWT Token",
        "content": {"application/json": {"example": {"detail": "Malformed JWT Token"}}},
    },
    status.HTTP_403_FORBIDDEN: {
        "model": ErrorDetail,
        "description": "Not authenticated",
        "content": {"application/json": {"example": {"detail": "Not authenticated"}}},
    },
    status.HTTP_404_NOT_FOUND: {
        "model": ErrorDetail,
        "description": "Entity not Found",
        "content": {"application/json": {"example": {"detail": "Entity not found."}}},
    },
}

api_router = APIRouter()
api_router.include_router(
    buckets.router,
    dependencies=[Depends(decode_bearer_token)],
    responses=alternative_responses,
)
api_router.include_router(
    s3key.router,
    dependencies=[Depends(decode_bearer_token)],
    responses=alternative_responses,
)
api_router.include_router(
    bucket_permissions.router,
    dependencies=[Depends(decode_bearer_token)],
    responses=alternative_responses,
)
