from typing import List

from opentelemetry import trace
from rgwadmin import RGWAdmin

from app.core.config import settings
from app.schemas.user import S3Key

tracer = trace.get_tracer_provider().get_tracer(__name__)

rgw = RGWAdmin(
    access_key=settings.USER_CEPH_ACCESS_KEY,
    secret_key=settings.USER_CEPH_SECRET_KEY,
    secure=str(settings.OBJECT_GATEWAY_URI).startswith("https"),
    server=str(settings.OBJECT_GATEWAY_URI).split("://")[-1][:-1],
)


def get_s3_keys(rgw: RGWAdmin, uid: str) -> List[S3Key]:
    with tracer.start_as_current_span("s3_get_user_keys") as span:
        span.set_attribute("uid", uid)
        return [S3Key(**key) for key in rgw.get_user(uid=uid, stats=False)["keys"]]
